This module only contains miscellaneous functions.
The components are defined in Doggo.Components.
Summary
JS
Hides the modal with the given ID.
Shows the modal with the given ID.
Shows the tab with the given index of the tabs/1 component with the given
ID.
Functions
Returns all component classes and data attributes used in the given components module.
JS
Hides the modal with the given ID.
Example
<.link phx-click={hide_modal("pet-modal")}>hide</.link>
Shows the modal with the given ID.
Example
<.link phx-click={show_modal("pet-modal")}>show</.link>
Shows the tab with the given index of the tabs/1 component with the given
ID.
Example
Doggo.show_tab("my-tabs", 2)